from frictionless import describe, Detector, validate, steps, Resource, transform
import matplotlib.pyplot as plt

# Descibe the data and detect missing values
detector = Detector(field_missing_values=["", "-1"])
resource = describe("zst1194_2019.csv", detector=detector)
resource.to_yaml("zst1194_2019.resource.yaml")

report = validate(Resource("zst1194_2019.resource.yaml"))

if not report.valid:
    print(report.flatten(["rowNumber", "fieldNumber", "type"]))
else:
    print("CSV file validated using frictionless.")

    # Filter the data table for a specific date
    source = Resource("zst1194_2019.resource.yaml")
    df = transform(
        source,
        steps=[
            steps.table_normalize(),
            steps.row_filter(formula="Datum == 190814")
        ]
    ).to_pandas()

    # Create Subplots
    fig, axs = plt.subplots(1, 2, figsize=(20,10))
    fig.suptitle("Composition of vehicles counted on Wednesday 14.08.2019")

    # Direction 1
    axs[0].stackplot(df["Stunde"] - 1, [df["Son_R1"], df["Mot_R1"], df["Lfw_R1"], df["Pkw_R1"],
                                  df["PmA_R1"], df["LoA_R1"], df["Lzg_R1"] - df["Sat_R1"], df["Sat_R1"], df["Bus_R1"]], 
                                  labels=["Son_R1", "Mot_R1", "Lfw_R1", "Pkw_R1",
                                  "PmA_R1", "LoA_R1", "LmA_R1", "Sat_R1", "Bus_R1"])
    axs[0].set_title("Direction 1")
    axs[0].legend()
    axs[0].set_xlabel("Hour of the day")
    axs[0].set_ylabel("Count")

    # Direction 2
    axs[1].stackplot(df["Stunde"] - 1, [df["Son_R2"], df["Mot_R2"], df["Lfw_R2"], df["Pkw_R2"],
                                  df["PmA_R2"], df["LoA_R2"], df["Lzg_R2"] - df["Sat_R2"], df["Sat_R2"], df["Bus_R2"]], 
                                  labels=["Son_R2", "Mot_R2", "Lfw_R2", "Pkw_R2",
                                  "PmA_R2", "LoA_R2", "LmA_R2", "Sat_R2", "Bus_R2"])
    axs[1].set_title("Direction 2")
    axs[1].legend()
    axs[1].set_xlabel("Hour of the day")
    axs[1].set_ylabel("Count")

    plt.savefig("output.png")